==> pymol_1.0.orig.tar.gz: pymol-1.0/modules/pymol2/make_cmd2.py <==

api_list = [
    'accept',
    'alias',
    'align',
    'alter',
    'alter_list',
    'alter_state',
    'angle',
    'as',
    'attach',
    'auto_measure',
    'backward',
    'bg_color',
    'bond',
    'button',
    'cartoon',
    'cd',
    'center',
    'check',
    'clip',
    'cls',
    'color',
    'commands',
    'config_mouse',
    'copy',
    'copy_image',
    'count_atoms',
    'count_frames',
    'count_states',
    'create',
    'cycle_valence',
    'decline',
    'delete',
    'deprotect',
    'deselect',
    'dihedral',
    'dir',
    'dirty',
    'disable',
    'distance',
    'do',
    'drag',
    'draw',
    'dss',
    'dummy',
    'dump',
    'edit',
    'edit_mode',
    'enable',
    'ending',
    'export_dots',
    'extend',
    'extract',
    'feedback',
    'fetch',
    'finish_object',
    'fit',
    'fix_chemistry',
    'flag',
    'forward',
    'fragment',
    'frame',
    'full_screen',
    'fuse',
    'get',
    'get_angle',
    'get_area',
    'get_atom_coords',
    'get_bond_print',
    'get_busy',
    'get_chains',
    'get_color_indices',
    'get_colorection',
    'get_dihedral',
    'get_distance',
    'get_editor_scheme',
    'get_extent',
    'get_frame',
    'get_state',
    'get_model',
    'get_movie_playing',
    'get_movie_locked',    
    'get_mtl_obj',
    'get_names',
    'get_object_list',
    'get_object_matrix',
    'get_pdbstr',
    'get_position',
    'get_povray',
    'get_session',
    'get_setting_boolean', 
    'get_setting_int',     
    'get_setting_float',   
    'get_setting_legacy',  
    'get_setting_tuple',   
    'get_setting_updates', 
    'get_setting_text',
    'get_symmetry',
    'get_title',
    'get_type',
    'get_wizard',
    'get_wizard_stack',
    'get_version',
    'get_view',
    'get_vis',
    'gradient',
    'group',
    'h_add',
    'h_fill',
    'h_fix',
    'help',
    'hide',
    'id_atom',
    'identify',
    'index',
    'indicate',
    'intra_fit',
    'intra_rms',
    'intra_rms_cur',
    'invert',
    'isodot',
    'isolevel',
    'isomesh',
    'isosurface',
    'iterate',
    'iterate_state',
    'label',
    'load',
    'load_embedded',
    'load_model',
    'load_png',
    'load_traj',
    'log',
    'log_close',
    'log_open',
    'ls',
    'madd',
    'map_double',
    'map_halve',
    'map_new',
    'map_set',
    'map_set_border',
    'map_trim',
    'mappend',
    'mask',
    'matrix_copy',
    'matrix_reset',
    'matrix_transfer',
    'mclear',
    'mdump',
    'mdo',
    'mem',
    'meter_reset',
    'middle',
    'mmatrix',
    'mouse',
    'move',
    'mplay',
    'mpng',
    'mray',
    'mset',
    'mstop',
    'mtoggle',
    'multisave',
    'mview',
    'order',
    'orient',
    'origin',
    'overlap',
    'pair_fit',
    'phi_psi',
    'png', 
    'pop',
    'protect',
    'pseudoatom',
    'push_undo',
    'pwd',
    'quit',
    'ramp_new',
    'ray',
    'read_molstr',
    'read_pdbstr',
    'rebuild',
    'recolor',
    'redo',
    'refresh',
    'refresh_wizard',
    'reinitialize',
    'remove',
    'remove_picked',
    'rename',
    'replace',
    'replace_wizard',
    'reset',
    'resume',
    'rewind',
    'rms',
    'rms_cur',
    'rock',
    'rotate',
    'save',
    'scene',
    'sculpt_activate',
    'sculpt_deactivate',
    'sculpt_iterate',
    'sculpt_purge',
    'select',
    'set',
    'set_bond',
    'set_color',
    'set_colorection',    
    'set_dihedral',
    'set_geometry',
    'set_key',
    'set_name',
    'set_session',
    'set_symmetry',
    'set_title',
    'set_view',
    'set_vis',
    'show',
    'show_as',
    'slice_new',
    'smooth',
    'sort',
    'space',
    'spectrum',
    'spheroid',
    'splash',
    'split_states',
    'stereo',
    'symexp',
    'sync',
    'system',
    'test',
    'toggle',
    'torsion',
    'translate',
    'turn',
    'unbond',
    'undo',
    'ungroup',
    'unmask',
    'unpick',
    'unprotect',
    'unset',
    'unset_bond',
    'update',
    'vdw_fit',
    'view',
    'viewport',
    'window',
    'wizard',
    'zoom'
    ]

import sys
import string

lines = open("cmd2.py").readlines()
if len(lines):
    file = open("cmd2.py","wa")
    for line in lines:
        file.write(line)
        if string.find(line, "AUTOGENERATED BEYOND THIS POINT")>=0:
            break

for fn in api_list:
    file.write('''
    def %s(self, *a, **k):
        k['_self']=self
        return apply(global_cmd.%s, a, k)
    '''%(fn,fn))

==> pymol_1.1.orig.tar.gz: pymol-1.1/modules/pymol2/make_cmd2.py <==

api_list = [
    '_feedback',
    '_special',
    '_ctrl',
    '_alt',
    'accept',
    'alias',
    'align',
    'alter',
    'alter_list',
    'alter_state',
    'angle',
    'as',
    'attach',
    'auto_measure',
    'backward',
    'bg_color',
    'bond',
    'button',
    'cache',
    'cartoon',    
    'capture',
    'cd',
    'center',
    'check',
    'clip',
    'cls',
    'color',
    'commands',
    'config_mouse',
    'copy',
    'copy_image',
    'count_atoms',
    'count_frames',
    'count_states',
    'create',
    'cycle_valence',
    'decline',
    'delete',
    'del_colorection',
    'deprotect',
    'deselect',
    'dihedral',
    'dir',
    'dirty',
    'disable',
    'distance',
    'dist',
    'do',
    'drag',
    'draw',
    'dss',
    'dummy',
    'dump',
    'edit',
    'edit_mode',
    'enable',
    'ending',
    'export_dots',
    'extend',
    'extract',
    'feedback',
    'fetch',
    'finish_object',
    'fit',
    'fix_chemistry',
    'flag',
    'forward',
    'fragment',
    'frame',
    'full_screen',
    'fuse',
    'get',
    'get_angle',
    'get_area',
    'get_atom_coords',
    'get_bond_print',
    'get_busy',
    'get_chains',
    'get_color_index',
    'get_color_indices',
    'get_colorection',
    'get_color_tuple',
    'get_dihedral',
    'get_distance',
    'get_editor_scheme',
    'get_extent',
    'get_frame',
    'get_model',
    'get_movie_playing',
    'get_movie_locked',
    'get_movie_length',
    'get_mtl_obj',
    'get_names',
    'get_names_of_type',
    'get_object_list',
    'get_object_matrix',
    'get_pdbstr',
    'get_position',
    'get_povray',
    'get_progress',
    'get_renderer',
    'get_scene_dict',
    'get_session',
    'get_setting_boolean', 
    'get_setting_int',     
    'get_setting_float',   
    'get_setting_legacy',  
    'get_setting_tuple',   
    'get_setting_updates', 
    'get_setting_text',
    'get_state',
    'get_symmetry',
    'get_title',
    'get_type',
    'get_wizard',
    'get_wizard_stack',
    'get_version',
    'get_view',
    'get_vis',
    'gradient',
    'group',
    'h_add',
    'h_fill',
    'h_fix',
    'help',
    'hide',
    'id_atom',
    'identify',
    'index',
    'indicate',
    'intra_fit',
    'intra_rms',
    'intra_rms_cur',
    'invert',
    'isodot',
    'isolevel',
    'isomesh',
    'isosurface',
    'iterate',
    'iterate_state',
    'label',
    'load',
    'load_cgo',
    'load_embedded',
    'load_model',
    'load_object',
    'load_png',
    'load_traj',
    'log',
    'log_close',
    'log_open',
    'ls',
    'madd',
    'map_double',
    'map_halve',
    'map_new',
    'map_set',
    'map_set_border',
    'map_trim',
    'mappend',
    'mask',
    'matrix_copy',
    'matrix_reset',
    'matrix_transfer',
    'mclear',
    'mdump',
    'mdo',
    'mem',
    'meter_reset',
    'middle',
    'mmatrix',
    'mouse',
    'move',
    'mplay',
    'mpng',
    'mray',
    'mset',
    'mstop',
    'mtoggle',
    'multisave',
    'mview',
    'order',
    'orient',
    'origin',
    'overlap',
    'pair_fit',
    'phi_psi',
    'png', 
    'pop',
    'protect',
    'pseudoatom',
    'push_undo',
    'pwd',
    'quit',
    'ramp_new',
    'ray',
    'read_molstr',
    'read_pdbstr',
    'ready',
    'rebuild',
    'recolor',
    'redo',
    'refresh',
    'refresh_wizard',
    'reinitialize',
    'remove',
    'remove_picked',
    'rename',
    'replace',
    'replace_wizard',
    'reset',
    'resume',
    'rewind',
    'rms',
    'rms_cur',
    'rock',
    'rotate',
    'save',
    'scene',
    'sculpt_activate',
    'sculpt_deactivate',
    'sculpt_iterate',
    'sculpt_purge',
    'select',
    'select_list',
    'set',
    'set_bond',
    'set_color',
    'set_colorection',    
    'set_dihedral',
    'set_geometry',
    'set_key',
    'set_name',
    'set_session',
    'set_symmetry',
    'set_title',
    'set_wizard',    
    'set_wizard_stack',
    'set_view',
    'set_vis',
    'show',
    'show_as',
    'slice_new',
    'smooth',
    'sort',
    'space',
    'spectrum',
    'spheroid',
    'splash',
    'split_states',
    'stereo',
    'symexp',
    'sync',
    'system',
    'test',
    'toggle',
    'torsion',
    'translate',
    'turn',
    'unbond',
    'undo',
    'ungroup',
    'unmask',
    'unpick',
    'unprotect',
    'unset',
    'unset_bond',
    'update',
    'valence',
    'vdw_fit',
    'view',
    'viewport',
    'window',
    'wizard',
    'zoom'
    ]

import sys
import string

lines = open("cmd2.py").readlines()
if len(lines):
    file = open("cmd2.py","wa")
    for line in lines:
        file.write(line)
        if string.find(line, "AUTOGENERATED BEYOND THIS POINT")>=0:
            break

for fn in api_list:
    file.write('''
    def %s(self, *a, **k):
        k['_self']=self
        return apply(global_cmd.%s, a, k)
    '''%(fn,fn))
